from unicourt.api_client import ApiClient
from unicourt.configuration import Configuration
from unicourt.api_response import ApiResponse

from unicourt.exceptions import OpenApiException
from unicourt.exceptions import ApiAttributeError
from unicourt.exceptions import ApiTypeError
from unicourt.exceptions import ApiValueError
from unicourt.exceptions import ApiKeyError
from unicourt.exceptions import ApiException
from unicourt.exceptions import SdkException

from unicourt.sdk.PartyAnalytics import PartyAnalytics
from unicourt.sdk.JudgeAnalytics import JudgeAnalytics
from unicourt.sdk.CaseAnalytics import CaseAnalytics
from unicourt.sdk.CaseUpdate import CaseUpdate
from unicourt.sdk.CaseExport import CaseExport
from unicourt.sdk.CourtAvailability import CourtAvailability
from unicourt.sdk.PACER import PACER
from unicourt.sdk.CaseDocket import CaseDocket
from unicourt.sdk.PACERCredential import PACERCredential
from unicourt.sdk.Callback import Callback
from unicourt.sdk.CaseSearch import CaseSearch
from unicourt.sdk.Authentication import Authentication
from unicourt.sdk.AttorneyAnalytics import AttorneyAnalytics
from unicourt.sdk.CourtStandards import CourtStandards
from unicourt.sdk.CaseTracking import CaseTracking
from unicourt.sdk.CaseDocuments import CaseDocuments
from unicourt.sdk.Usage import Usage
from unicourt.sdk.LawFirmAnalytics import LawFirmAnalytics

from unicourt.model.access_token_id_list_response import AccessTokenIdListResponse
from unicourt.model.access_token_id_response import AccessTokenIdResponse
from unicourt.model.access_token_request import AccessTokenRequest
from unicourt.model.access_token_response import AccessTokenResponse
from unicourt.model.additional_levels import AdditionalLevels
from unicourt.model.address import Address
from unicourt.model.area_of_law import AreaOfLaw
from unicourt.model.area_of_law_response import AreaOfLawResponse
from unicourt.model.associated_norm_attorney import AssociatedNormAttorney
from unicourt.model.associated_norm_attorney_response import AssociatedNormAttorneyResponse
from unicourt.model.associated_norm_judge import AssociatedNormJudge
from unicourt.model.associated_norm_judge_response import AssociatedNormJudgeResponse
from unicourt.model.associated_norm_law_firm import AssociatedNormLawFirm
from unicourt.model.associated_norm_law_firm_response import AssociatedNormLawFirmResponse
from unicourt.model.associated_norm_party import AssociatedNormParty
from unicourt.model.associated_norm_party_response import AssociatedNormPartyResponse
from unicourt.model.associated_so_s_person import AssociatedSoSPerson
from unicourt.model.attorney import Attorney
from unicourt.model.attorney_analytics_api import AttorneyAnalyticsAPI
from unicourt.model.attorney_law_firm import AttorneyLawFirm
from unicourt.model.attorney_representation_type import AttorneyRepresentationType
from unicourt.model.attorney_representation_type_response import AttorneyRepresentationTypeResponse
from unicourt.model.attorney_type import AttorneyType
from unicourt.model.attorney_type_response import AttorneyTypeResponse
from unicourt.model.attorneys import Attorneys
from unicourt.model.bar_record import BarRecord
from unicourt.model.bar_record_preview import BarRecordPreview
from unicourt.model.bar_source_data import BarSourceData
from unicourt.model.bar_source_data_administrative_actions_array_inner import BarSourceDataAdministrativeActionsArrayInner
from unicourt.model.bar_source_data_advanced_degree_array_inner import BarSourceDataAdvancedDegreeArrayInner
from unicourt.model.bar_source_data_bar_status_array_inner import BarSourceDataBarStatusArrayInner
from unicourt.model.bar_source_data_board_certifications_array_inner import BarSourceDataBoardCertificationsArrayInner
from unicourt.model.bar_source_data_committees_array_inner import BarSourceDataCommitteesArrayInner
from unicourt.model.bar_source_data_court_history_array_inner import BarSourceDataCourtHistoryArrayInner
from unicourt.model.bar_source_data_court_of_admissions import BarSourceDataCourtOfAdmissions
from unicourt.model.bar_source_data_disciplinary_history_array_inner import BarSourceDataDisciplinaryHistoryArrayInner
from unicourt.model.bar_source_data_discipline_summaries_array_inner import BarSourceDataDisciplineSummariesArrayInner
from unicourt.model.bar_source_data_employment_history_array_inner import BarSourceDataEmploymentHistoryArrayInner
from unicourt.model.bar_source_data_fees_options_array_inner import BarSourceDataFeesOptionsArrayInner
from unicourt.model.bar_source_data_involvements_array_inner import BarSourceDataInvolvementsArrayInner
from unicourt.model.bar_source_data_law_school_array_inner import BarSourceDataLawSchoolArrayInner
from unicourt.model.bar_source_data_name import BarSourceDataName
from unicourt.model.bar_source_data_open_action_status_array_inner import BarSourceDataOpenActionStatusArrayInner
from unicourt.model.bar_source_data_other_jurisdiction_array_inner import BarSourceDataOtherJurisdictionArrayInner
from unicourt.model.bar_source_data_public_hearing_array_inner import BarSourceDataPublicHearingArrayInner
from unicourt.model.bar_source_data_reason_for_inactivation import BarSourceDataReasonForInactivation
from unicourt.model.bar_source_data_related_cases_array_inner import BarSourceDataRelatedCasesArrayInner
from unicourt.model.bar_source_data_source_info import BarSourceDataSourceInfo
from unicourt.model.bar_source_data_statewide_grievance_committee_history_array_inner import BarSourceDataStatewideGrievanceCommitteeHistoryArrayInner
from unicourt.model.bar_source_data_status_history_array_inner import BarSourceDataStatusHistoryArrayInner
from unicourt.model.bar_source_data_ten_year_discipline_array_inner import BarSourceDataTenYearDisciplineArrayInner
from unicourt.model.billing_cycle_usage_response import BillingCycleUsageResponse
from unicourt.model.billing_cycle_usage_response_api_calls_billable import BillingCycleUsageResponseApiCallsBillable
from unicourt.model.billing_cycle_usage_response_api_calls_credited import BillingCycleUsageResponseApiCallsCredited
from unicourt.model.billing_cycle_usage_response_api_calls_made import BillingCycleUsageResponseApiCallsMade
from unicourt.model.billing_cycle_usage_response_billing_cycle import BillingCycleUsageResponseBillingCycle
from unicourt.model.billing_cycles_response import BillingCyclesResponse
from unicourt.model.callback_list_response import CallbackListResponse
from unicourt.model.callback_list_response_case_document_order_callbacks import CallbackListResponseCaseDocumentOrderCallbacks
from unicourt.model.case import Case
from unicourt.model.case_analytics_api import CaseAnalyticsAPI
from unicourt.model.case_cause_of_action import CaseCauseOfAction
from unicourt.model.case_charge import CaseCharge
from unicourt.model.case_class import CaseClass
from unicourt.model.case_class_coverage import CaseClassCoverage
from unicourt.model.case_class_response import CaseClassResponse
from unicourt.model.case_count_analytics_by_area_of_law import CaseCountAnalyticsByAreaOfLaw
from unicourt.model.case_count_analytics_by_area_of_law_response import CaseCountAnalyticsByAreaOfLawResponse
from unicourt.model.case_count_analytics_by_case_class import CaseCountAnalyticsByCaseClass
from unicourt.model.case_count_analytics_by_case_class_response import CaseCountAnalyticsByCaseClassResponse
from unicourt.model.case_count_analytics_by_case_filed_date import CaseCountAnalyticsByCaseFiledDate
from unicourt.model.case_count_analytics_by_case_filed_date_response import CaseCountAnalyticsByCaseFiledDateResponse
from unicourt.model.case_count_analytics_by_case_type import CaseCountAnalyticsByCaseType
from unicourt.model.case_count_analytics_by_case_type_group import CaseCountAnalyticsByCaseTypeGroup
from unicourt.model.case_count_analytics_by_case_type_group_response import CaseCountAnalyticsByCaseTypeGroupResponse
from unicourt.model.case_count_analytics_by_case_type_response import CaseCountAnalyticsByCaseTypeResponse
from unicourt.model.case_count_analytics_by_court import CaseCountAnalyticsByCourt
from unicourt.model.case_count_analytics_by_court_geo import CaseCountAnalyticsByCourtGeo
from unicourt.model.case_count_analytics_by_court_location import CaseCountAnalyticsByCourtLocation
from unicourt.model.case_count_analytics_by_court_location_response import CaseCountAnalyticsByCourtLocationResponse
from unicourt.model.case_count_analytics_by_court_response import CaseCountAnalyticsByCourtResponse
from unicourt.model.case_count_analytics_by_court_system import CaseCountAnalyticsByCourtSystem
from unicourt.model.case_count_analytics_by_court_system_response import CaseCountAnalyticsByCourtSystemResponse
from unicourt.model.case_count_analytics_by_court_type import CaseCountAnalyticsByCourtType
from unicourt.model.case_count_analytics_by_court_type_response import CaseCountAnalyticsByCourtTypeResponse
from unicourt.model.case_count_analytics_by_jurisdiction_geo import CaseCountAnalyticsByJurisdictionGeo
from unicourt.model.case_count_analytics_by_jurisdiction_geo_response import CaseCountAnalyticsByJurisdictionGeoResponse
from unicourt.model.case_count_analytics_by_norm_attorney import CaseCountAnalyticsByNormAttorney
from unicourt.model.case_count_analytics_by_norm_attorney_response import CaseCountAnalyticsByNormAttorneyResponse
from unicourt.model.case_count_analytics_by_norm_judge import CaseCountAnalyticsByNormJudge
from unicourt.model.case_count_analytics_by_norm_judge_response import CaseCountAnalyticsByNormJudgeResponse
from unicourt.model.case_count_analytics_by_norm_law_firm import CaseCountAnalyticsByNormLawFirm
from unicourt.model.case_count_analytics_by_norm_law_firm_response import CaseCountAnalyticsByNormLawFirmResponse
from unicourt.model.case_count_analytics_by_norm_party import CaseCountAnalyticsByNormParty
from unicourt.model.case_count_analytics_by_norm_party_response import CaseCountAnalyticsByNormPartyResponse
from unicourt.model.case_count_analytics_by_party_role import CaseCountAnalyticsByPartyRole
from unicourt.model.case_count_analytics_by_party_role_group import CaseCountAnalyticsByPartyRoleGroup
from unicourt.model.case_count_analytics_by_party_role_group_response import CaseCountAnalyticsByPartyRoleGroupResponse
from unicourt.model.case_count_analytics_by_party_role_response import CaseCountAnalyticsByPartyRoleResponse
from unicourt.model.case_document import CaseDocument
from unicourt.model.case_document_order_callback import CaseDocumentOrderCallback
from unicourt.model.case_document_order_callback_list_response import CaseDocumentOrderCallbackListResponse
from unicourt.model.case_document_order_pacer_options import CaseDocumentOrderPacerOptions
from unicourt.model.case_document_order_request import CaseDocumentOrderRequest
from unicourt.model.case_documents import CaseDocuments
from unicourt.model.case_export_callback import CaseExportCallback
from unicourt.model.case_export_callback_list_response import CaseExportCallbackListResponse
from unicourt.model.case_relationship_type import CaseRelationshipType
from unicourt.model.case_relationship_type_response import CaseRelationshipTypeResponse
from unicourt.model.case_search_response import CaseSearchResponse
from unicourt.model.case_search_result import CaseSearchResult
from unicourt.model.case_stats import CaseStats
from unicourt.model.case_status import CaseStatus
from unicourt.model.case_status_group import CaseStatusGroup
from unicourt.model.case_status_group_response import CaseStatusGroupResponse
from unicourt.model.case_status_response import CaseStatusResponse
from unicourt.model.case_timeline import CaseTimeline
from unicourt.model.case_track import CaseTrack
from unicourt.model.case_track_list_response import CaseTrackListResponse
from unicourt.model.case_track_preview import CaseTrackPreview
from unicourt.model.case_track_request import CaseTrackRequest
from unicourt.model.case_track_schedule import CaseTrackSchedule
from unicourt.model.case_type import CaseType
from unicourt.model.case_type_group import CaseTypeGroup
from unicourt.model.case_type_group_response import CaseTypeGroupResponse
from unicourt.model.case_type_response import CaseTypeResponse
from unicourt.model.case_update import CaseUpdate
from unicourt.model.case_update_list_response import CaseUpdateListResponse
from unicourt.model.case_update_pacer_options import CaseUpdatePacerOptions
from unicourt.model.case_update_pacer_options_additional_page_array_inner import CaseUpdatePacerOptionsAdditionalPageArrayInner
from unicourt.model.case_update_pacer_options_response import CaseUpdatePacerOptionsResponse
from unicourt.model.case_update_preview import CaseUpdatePreview
from unicourt.model.case_update_request import CaseUpdateRequest
from unicourt.model.cause_of_action import CauseOfAction
from unicourt.model.cause_of_action_additional_data import CauseOfActionAdditionalData
from unicourt.model.cause_of_action_additional_data_response import CauseOfActionAdditionalDataResponse
from unicourt.model.cause_of_action_group import CauseOfActionGroup
from unicourt.model.cause_of_action_group_response import CauseOfActionGroupResponse
from unicourt.model.cause_of_action_response import CauseOfActionResponse
from unicourt.model.charge import Charge
from unicourt.model.charge_additional_data import ChargeAdditionalData
from unicourt.model.charge_additional_data_response import ChargeAdditionalDataResponse
from unicourt.model.charge_degree import ChargeDegree
from unicourt.model.charge_degree_response import ChargeDegreeResponse
from unicourt.model.charge_group import ChargeGroup
from unicourt.model.charge_group_response import ChargeGroupResponse
from unicourt.model.charge_response import ChargeResponse
from unicourt.model.charge_severity import ChargeSeverity
from unicourt.model.charge_severity_response import ChargeSeverityResponse
from unicourt.model.contact import Contact
from unicourt.model.court import Court
from unicourt.model.court_coverage import CourtCoverage
from unicourt.model.court_location import CourtLocation
from unicourt.model.court_location_response import CourtLocationResponse
from unicourt.model.court_response import CourtResponse
from unicourt.model.court_service_status import CourtServiceStatus
from unicourt.model.court_service_status_response import CourtServiceStatusResponse
from unicourt.model.court_system import CourtSystem
from unicourt.model.court_system_response import CourtSystemResponse
from unicourt.model.court_type import CourtType
from unicourt.model.court_type_response import CourtTypeResponse
from unicourt.model.daily_usage_response import DailyUsageResponse
from unicourt.model.docket_entries import DocketEntries
from unicourt.model.docket_entry import DocketEntry
from unicourt.model.docket_entry_primary_documents import DocketEntryPrimaryDocuments
from unicourt.model.docket_entry_secondary_documents import DocketEntrySecondaryDocuments
from unicourt.model.document_download import DocumentDownload
from unicourt.model.email import Email
from unicourt.model.exception import Exception
from unicourt.model.export_file import ExportFile
from unicourt.model.extracted_fields import ExtractedFields
from unicourt.model.hearing import Hearing
from unicourt.model.hearings import Hearings
from unicourt.model.individual import Individual
from unicourt.model.invalidate_access_token_request import InvalidateAccessTokenRequest
from unicourt.model.judge import Judge
from unicourt.model.judge_analytics_api import JudgeAnalyticsAPI
from unicourt.model.judge_type import JudgeType
from unicourt.model.judge_type_response import JudgeTypeResponse
from unicourt.model.judges import Judges
from unicourt.model.jurisdiction_geo import JurisdictionGeo
from unicourt.model.jurisdiction_geo_response import JurisdictionGeoResponse
from unicourt.model.last_tracked_details import LastTrackedDetails
from unicourt.model.law_firm_analytics_api import LawFirmAnalyticsAPI
from unicourt.model.matched_object import MatchedObject
from unicourt.model.nature_of_suit import NatureOfSuit
from unicourt.model.norm_attorney import NormAttorney
from unicourt.model.norm_attorney_search_response import NormAttorneySearchResponse
from unicourt.model.norm_attorney_search_result import NormAttorneySearchResult
from unicourt.model.norm_corporate_group import NormCorporateGroup
from unicourt.model.norm_judge import NormJudge
from unicourt.model.norm_judge_public_data import NormJudgePublicData
from unicourt.model.norm_judge_public_data_aba_ratings import NormJudgePublicDataAbaRatings
from unicourt.model.norm_judge_public_data_bio import NormJudgePublicDataBio
from unicourt.model.norm_judge_public_data_education_array_inner import NormJudgePublicDataEducationArrayInner
from unicourt.model.norm_judge_public_data_judicial_source import NormJudgePublicDataJudicialSource
from unicourt.model.norm_judge_public_data_name_history_array_inner import NormJudgePublicDataNameHistoryArrayInner
from unicourt.model.norm_judge_search_response import NormJudgeSearchResponse
from unicourt.model.norm_judge_search_result import NormJudgeSearchResult
from unicourt.model.norm_law_firm import NormLawFirm
from unicourt.model.norm_law_firm_search_response import NormLawFirmSearchResponse
from unicourt.model.norm_law_firm_search_result import NormLawFirmSearchResult
from unicourt.model.norm_organization import NormOrganization
from unicourt.model.norm_organization_ticker_array_inner import NormOrganizationTickerArrayInner
from unicourt.model.norm_party import NormParty
from unicourt.model.norm_party_search_response import NormPartySearchResponse
from unicourt.model.norm_party_search_result import NormPartySearchResult
from unicourt.model.pacer_case_search_content import PACERCaseSearchContent
from unicourt.model.pacer_case_search_results import PACERCaseSearchResults
from unicourt.model.pacer_import_case import PACERImportCase
from unicourt.model.pacer_import_case_results import PACERImportCaseResults
from unicourt.model.pacer_party_search_content import PACERPartySearchContent
from unicourt.model.pacer_party_search_results import PACERPartySearchResults
from unicourt.model.pacer_search_page_info import PACERSearchPageInfo
from unicourt.model.pacer_search_receipt import PACERSearchReceipt
from unicourt.model.pcl_case import PCLCase
from unicourt.model.pcl_party import PCLParty
from unicourt.model.pacer_credential import PacerCredential
from unicourt.model.pacer_credential_list_response import PacerCredentialListResponse
from unicourt.model.pacer_credential_request import PacerCredentialRequest
from unicourt.model.parties import Parties
from unicourt.model.party import Party
from unicourt.model.party_analytics_api import PartyAnalyticsAPI
from unicourt.model.party_attorney_association import PartyAttorneyAssociation
from unicourt.model.party_attorney_associations import PartyAttorneyAssociations
from unicourt.model.party_role import PartyRole
from unicourt.model.party_role_group import PartyRoleGroup
from unicourt.model.party_role_group_response import PartyRoleGroupResponse
from unicourt.model.party_role_response import PartyRoleResponse
from unicourt.model.phone import Phone
from unicourt.model.possible_norm_attorney import PossibleNormAttorney
from unicourt.model.possible_norm_attorney_score_constituents import PossibleNormAttorneyScoreConstituents
from unicourt.model.possible_norm_judge import PossibleNormJudge
from unicourt.model.possible_norm_judge_score_constituents import PossibleNormJudgeScoreConstituents
from unicourt.model.possible_norm_law_firm import PossibleNormLawFirm
from unicourt.model.possible_norm_law_firm_score_constituents import PossibleNormLawFirmScoreConstituents
from unicourt.model.possible_norm_law_firm_source_details import PossibleNormLawFirmSourceDetails
from unicourt.model.possible_norm_party import PossibleNormParty
from unicourt.model.possible_norm_party_score_constituents import PossibleNormPartyScoreConstituents
from unicourt.model.preview_document import PreviewDocument
from unicourt.model.raw_ordered_data import RawOrderedData
from unicourt.model.raw_ordered_data_child import RawOrderedDataChild
from unicourt.model.raw_ordered_data_child_child_array_inner import RawOrderedDataChildChildArrayInner
from unicourt.model.referenced_docket_number import ReferencedDocketNumber
from unicourt.model.related_case import RelatedCase
from unicourt.model.related_cases import RelatedCases
from unicourt.model.related_norm_party import RelatedNormParty
from unicourt.model.sos_associated_norm_organization import SOSAssociatedNormOrganization
from unicourt.model.sos_data import SOSData
from unicourt.model.sos_data_preview import SOSDataPreview
from unicourt.model.sos_name_change import SOSNameChange
from unicourt.model.schedule import Schedule
from unicourt.model.service_history import ServiceHistory
from unicourt.model.service_status import ServiceStatus
from unicourt.model.service_status_down_details import ServiceStatusDownDetails
from unicourt.model.similar_norm_attorney import SimilarNormAttorney
from unicourt.model.source_case_data import SourceCaseData
from unicourt.model.source_cause_of_action import SourceCauseOfAction
from unicourt.model.source_charge import SourceCharge
from unicourt.model.source_charge_additional_data import SourceChargeAdditionalData
from unicourt.model.source_page_data import SourcePageData
from unicourt.model.source_structured_data import SourceStructuredData
from unicourt.model.success import Success


ACCESS_TOKEN = ""
TOKEN_ID = ""
CLIENT_ID = ""
CLIENT_SECRET = ""
api_client = None
configuration = None
