# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from unicourt.model.charge import Charge
from unicourt.model.charge_additional_data import ChargeAdditionalData
from unicourt.model.charge_degree import ChargeDegree
from unicourt.model.charge_severity import ChargeSeverity
from typing import Optional, Set
from typing_extensions import Self

class CaseCharge(BaseModel):
    """
    CaseCharge
    """ # noqa: E501
    object: Optional[Annotated[str, Field(min_length=10, strict=True, max_length=10)]] = Field(default='CaseCharge', description="Name of the object")
    charge: Optional[Charge] = None
    charge_degree: Optional[ChargeDegree] = Field(default=None, alias="chargeDegree")
    charge_severity: Optional[ChargeSeverity] = Field(default=None, alias="chargeSeverity")
    charge_additional_data_array: Optional[List[ChargeAdditionalData]] = Field(default=None, alias="chargeAdditionalDataArray")
    __properties: ClassVar[List[str]] = ["object", "charge", "chargeDegree", "chargeSeverity", "chargeAdditionalDataArray"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CaseCharge from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of charge
        if self.charge:
            _dict['charge'] = self.charge.to_dict()
        # override the default output from pydantic by calling `to_dict()` of charge_degree
        if self.charge_degree:
            _dict['chargeDegree'] = self.charge_degree.to_dict()
        # override the default output from pydantic by calling `to_dict()` of charge_severity
        if self.charge_severity:
            _dict['chargeSeverity'] = self.charge_severity.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in charge_additional_data_array (list)
        _items = []
        if self.charge_additional_data_array:
            for _item in self.charge_additional_data_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['chargeAdditionalDataArray'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CaseCharge from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'CaseCharge',
            "charge": Charge.from_dict(obj["charge"]) if obj.get("charge") is not None else None,
            "chargeDegree": ChargeDegree.from_dict(obj["chargeDegree"]) if obj.get("chargeDegree") is not None else None,
            "chargeSeverity": ChargeSeverity.from_dict(obj["chargeSeverity"]) if obj.get("chargeSeverity") is not None else None,
            "chargeAdditionalDataArray": [ChargeAdditionalData.from_dict(_item) for _item in obj["chargeAdditionalDataArray"]] if obj.get("chargeAdditionalDataArray") is not None else None
        })
        return _obj


