# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from unicourt.model.service_status_down_details import ServiceStatusDownDetails
from typing import Optional, Set
from typing_extensions import Self

class ServiceStatus(BaseModel):
    """
    ServiceStatus
    """ # noqa: E501
    object: Optional[Annotated[str, Field(min_length=13, strict=True, max_length=13)]] = Field(default='ServiceStatus', description="Name of the object")
    service_up: Optional[StrictBool] = Field(default=None, description="Status of Case Update Services Status.", alias="serviceUp")
    service_details: Optional[StrictStr] = Field(default=None, description="Status Details of Case Update Services Status.", alias="serviceDetails")
    service_status_down_details: Optional[ServiceStatusDownDetails] = Field(default=None, alias="serviceStatusDownDetails")
    __properties: ClassVar[List[str]] = ["object", "serviceUp", "serviceDetails", "serviceStatusDownDetails"]

    @field_validator('service_details')
    def service_details_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['acceptingCaseUpdates', 'notAcceptingCaseUpdates', 'acceptingCaseTrack', 'notAcceptingCaseTrack', 'acceptingAutoDocOrders', 'acceptingManualDocOrders', 'notAcceptingAutoDocOrdersLimitExceeded', 'notAcceptingManualDocOrdersLimitExceeded', 'notAcceptingDocOrders']):
            raise ValueError("must be one of enum values ('acceptingCaseUpdates', 'notAcceptingCaseUpdates', 'acceptingCaseTrack', 'notAcceptingCaseTrack', 'acceptingAutoDocOrders', 'acceptingManualDocOrders', 'notAcceptingAutoDocOrdersLimitExceeded', 'notAcceptingManualDocOrdersLimitExceeded', 'notAcceptingDocOrders')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServiceStatus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of service_status_down_details
        if self.service_status_down_details:
            _dict['serviceStatusDownDetails'] = self.service_status_down_details.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServiceStatus from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'ServiceStatus',
            "serviceUp": obj.get("serviceUp"),
            "serviceDetails": obj.get("serviceDetails"),
            "serviceStatusDownDetails": ServiceStatusDownDetails.from_dict(obj["serviceStatusDownDetails"]) if obj.get("serviceStatusDownDetails") is not None else None
        })
        return _obj


