# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class PacerCredentialRequest(BaseModel):
    """
    PacerCredentialRequest
    """ # noqa: E501
    pacer_user_id: Annotated[str, Field(min_length=6, strict=True, max_length=40)] = Field(description="Pacer User Id.", alias="pacerUserId")
    default_pacer_client_code: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=32)]] = Field(default=None, description="This is mandatory if your setting in PACER website is set to Yes for the flag `Require Client Code?` under `Set PACER Billing Preferences` page. The client code is a text field entered by users upon login that can be used to track usage by person, client matter number, or other meaningful entry up to 32 characters, comprising the following:    Alphabetic characters (A-Z or a-z)    Numeric digits (0-9)   Period (.)    Underscore (_)    Hyphen (-)    Slash (/)", alias="defaultPacerClientCode")
    password: Annotated[str, Field(min_length=8, strict=True, max_length=45)] = Field(description="Password.")
    __properties: ClassVar[List[str]] = ["pacerUserId", "defaultPacerClientCode", "password"]

    @field_validator('default_pacer_client_code')
    def default_pacer_client_code_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[a-zA-Z0-9._\-\/]+$", value):
            raise ValueError(r"must validate the regular expression /^[a-zA-Z0-9._\-\/]+$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PacerCredentialRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if default_pacer_client_code (nullable) is None
        # and model_fields_set contains the field
        if self.default_pacer_client_code is None and "default_pacer_client_code" in self.model_fields_set:
            _dict['defaultPacerClientCode'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PacerCredentialRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "pacerUserId": obj.get("pacerUserId"),
            "defaultPacerClientCode": obj.get("defaultPacerClientCode"),
            "password": obj.get("password")
        })
        return _obj


